from cherrytemplate import renderTemplate

from utils import *

from sqlobject import *

from datetime import datetime

from sets import Set

from connection import conn
from index import WebRoot

class Blog(SQLObject):
    _connection = conn
    _defaultOrder="-date"
    title = StringCol()
    content = StringCol()
    author = ForeignKey("Admin")
    date = DateTimeCol()
    private = BoolCol()


class WebBlog(WebRoot):
    def default(self, *args):
        if len(args) == 1:
            return self.view(args[0])
        
    default.exposed = True

    def index(self):
        return self.view(None)
    
    index.exposed = True

    def view(self, id):
        if id == None:
            entries = Blog.selectBy(private=False)
            entries = entries[:10]
        else:
            entries = Blog.selectBy(authorID=id)

        if entries.count():
            
            # FIXME : This is horrible, and should be handled by sqlobjet !
            # Here, we're getting all bloggers and remove all duplicates
            # How to do "distinct" with sqlobject ?

            def sql_distinct(res):
                old = -1
                nres = list()
            
                for r in res:
                    if old != r.author.id:
                        nres.append(r)
                        old = r.author.id

                return nres

            # ----

            people = sql_distinct(Blog.select())

            html = renderTemplate(file="templates/blog_view.html")
        else:
            html = "This developer does not exist or has never blogged."

        return self.render(html)
    
    view.exposed = True

    def delete(self, id, conf="no"):
        entry = Blog.get(id)
        # Check if this is user's blog
        if cherrypy.session.get("id") != entry.author.id:
            return self.render("This is not yours...")

        if conf == "yes":
            Blog.delete(id)
            raise cherrypy.HTTPRedirect("/blog")
        else:
            conf_msg = "Do you really want to delete entry '%s' ?" % entry.title
            conf_yes = "delete"

            conf_hidden = {"conf" : "yes",
                           "id" : id}

            html = renderTemplate(file="templates/confirm_action.html")
            
            return self.render(html)

    delete = adminOnly(delete)


    def edit(self, id, title=None, content=None, private=False):
        entry = Blog.get(id)
        
        # Check if this is user's blog
        if cherrypy.session.get("id") != int(entry.author.id):
            return self.render("This is not yours...")


        if title and content:
            entry.title = title
            entry.content = content
            entry.private = private

            raise cherrypy.HTTPRedirect("/blog")
        else:
            html = renderTemplate(file="templates/blog_edit.html")
            return self.render(html)

    edit = adminOnly(edit)
                
        
    def add(self, id, title=None, content=None, private=False):
        # Check if this is user's blog
        if cherrypy.session.get("id") != int(id):
            return self.render("This is not yours...")
        
        if title and content:
            d = datetime.now()

            Blog(title=title,
                 content=content,
                 date=d,
                 authorID=id,
                 private=private)

            raise cherrypy.HTTPRedirect("%s"%id)
            

        html = renderTemplate(file="templates/blog_add.html")
        return self.render(html)

    add = adminOnly(add)
    
